#import "HttpDnsPlugin.h"
#import <AlicloudHttpDNS/AlicloudHttpDNS.h>

@interface HttpDnsPlugin ()< HttpDNSDegradationDelegate >

@end

@implementation HttpDnsPlugin
+ (void)registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {
  FlutterMethodChannel* channel = [FlutterMethodChannel
      methodChannelWithName:@"http_dns"
            binaryMessenger:[registrar messenger]];
  HttpDnsPlugin* instance = [[HttpDnsPlugin alloc] init];
  [registrar addMethodCallDelegate:instance channel:channel];
}

- (void)handleMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {
  if ([@"getPlatformVersion" isEqualToString:call.method]) {
    result([@"iOS " stringByAppendingString:[[UIDevice currentDevice] systemVersion]]);
  } else if ([@"setup" isEqualToString:call.method]) {
      [self setup:call result:result];
  }else if ([@"getIpByUrl" isEqualToString:call.method]) {
      [self getIpByUrl:call result:result];
  }else if ([@"getIpsByUrl" isEqualToString:call.method]) {
      [self getIpsByUrl:call result:result];
  }else {
    result(FlutterMethodNotImplemented);
  }
}

- (void)setup:(FlutterMethodCall*)call result:(FlutterResult)result {
    // Override point for customization after application launch.
    // 初始化HTTPDNS
    // 设置AccoutID

    
    @try {
        NSDictionary *arguments = call.arguments;
        HttpDnsService *httpdns;
        if (arguments[@"accountID"]) {
            if(arguments[@"secretKey"]){
                httpdns = [[HttpDnsService alloc] initWithAccountID:[arguments[@"accountID"] intValue] secretKey:arguments[@"secretKey"]];
            }else{
                httpdns = [[HttpDnsService alloc] initWithAccountID:[arguments[@"accountID"] intValue]];
            }
        }else{
            result(@"not found accountID");
            return;
        }
    
        //鉴权方式初始化
        //HttpDnsService *httpdns = [[HttpDnsService alloc] initWithAccountID:0000 secretKey:@"XXXX"];
        
        if ([arguments[@"preResolveHosts"] isKindOfClass:[NSArray class]]) {
            [httpdns setPreResolveHosts:arguments[@"preResolveHosts"]];
        }
        if ([arguments[@"expiredIPEnabled"] boolValue]) {
            // 允许返回过期的IP
            [httpdns setExpiredIPEnabled:arguments[@"expiredIPEnabled"]||false];
        }
        
        if ([arguments[@"logEnabled"] stringValue]) {
            // 打开HTTPDNS Log，线上建议关闭
            [httpdns setLogEnabled:arguments[@"logEnabled"]||false];
        }

        [httpdns setDelegateForDegradationFilter:self];
        result(@"ok");
    } @catch (NSException *exception) {
        result([NSString stringWithFormat:@"%@",exception]);
        NSLog(@"%@",exception);

    } @finally {
        NSLog(@"@finally");

    }
}

- (void)getIpByUrl:(FlutterMethodCall*)call result:(FlutterResult)result {
    NSString *originalUrl = call.arguments;
    NSUInteger delaySeconds = 1;
    dispatch_time_t when = dispatch_time(DISPATCH_TIME_NOW, (int64_t)(delaySeconds * NSEC_PER_SEC));
    dispatch_after(when, dispatch_get_main_queue(), ^{
        NSURL *url = [NSURL URLWithString:originalUrl];
        HttpDnsService *httpdns = [HttpDnsService sharedInstance];
        NSString *ip = [httpdns getIpByHostAsync:url.host];
        NSLog(@"%@",url.host);
        if (ip) {
            result(ip);
        } else {
            result(@"");
        }

    });
}

- (void)getIpsByUrl:(FlutterMethodCall*)call result:(FlutterResult)result {
    NSString *originalUrl = call.arguments;
    NSUInteger delaySeconds = 1;
    dispatch_time_t when = dispatch_time(DISPATCH_TIME_NOW, (int64_t)(delaySeconds * NSEC_PER_SEC));
    dispatch_after(when, dispatch_get_main_queue(), ^{
        NSURL *url = [NSURL URLWithString:originalUrl];
        HttpDnsService *httpdns = [HttpDnsService sharedInstance];
        NSArray *ips = [httpdns getIpsByHostAsync:url.host];
        NSLog(@"%@",url.host);
        if (ips) {
            result(ips);
        } else {
            result(@[]);
        }

    });
}

/*
 * 降级过滤器，您可以自己定义HTTPDNS降级机制
 */
- (BOOL)shouldDegradeHTTPDNS:(NSString *)hostName {
    NSLog(@"Enters Degradation filter.");

    // 假设您禁止"www.taobao.com"域名通过HTTPDNS进行解析
    if ([hostName isEqualToString:@"www.taobao.com"]) {
        NSLog(@"The host is in blacklist. Degrade!");
        return YES;
    }

    return NO;
}

@end
