import 'dart:async';

import 'package:flutter/services.dart';

class HttpDns {
  static const MethodChannel _channel =
      const MethodChannel('http_dns');

  static Future setup({
    String accountID,
    String secretKey,
    bool expiredIPEnabled:true,
    bool logEnabled :false,
    List preResolveHosts : const [],
  }) async {
    return await _channel.invokeMethod('setup',{
      'accountID':accountID, //必填项
      'secretKey':secretKey, //选填项
      'expiredIPEnabled':expiredIPEnabled, //选填项
      'logEnabled':logEnabled, //选填项
      'preResolveHosts':preResolveHosts, //选填项
    });
  }

  static Future<String> getIpByUrl({
    String url,
    int retryIndex = 3,
    Duration retryDuration = const Duration(milliseconds: 500),
  }) async {
    var str =  await _channel.invokeMethod('getIpByUrl',url);
    if(str == null && retryIndex > 0){
      await Future.delayed(retryDuration);
      str = await getIpByUrl(url:url,retryIndex:retryIndex - 1);
    }
    return str;
  }

  static Future<List> getIpsByUrl({
    String url,
  }) async {
    return await _channel.invokeMethod('getIpsByUrl',url);
  }

//  static Future<String> get platformVersion async {
//    final String version = await _channel.invokeMethod('getPlatformVersion');
//    return version;
//  }
}
